@@ -118,7 +118,7 @@ def serialize(src, fields=None, related=None, include=None, exclude=None,
 
     By default, all the model fields (and only the model fields) are
     serialized. If the field is a Python primitive, it is serialized as such,
-    otherwise it is converted to string in utf8 encoding.
+    otherwise it is converted to string in utf-8 encoding.
 
     If `fields` is specified, it is a list of attribute descriptions to be
     serialized, replacing the default (all model fields). If `include` is
@@ -190,7 +190,9 @@ def serialize(src, fields=None, related=None, include=None, exclude=None,
     if isinstance(src, models.Manager):
         return [subs(i) for i in src.all()]
 
-    elif isinstance(src, list) or isinstance(src, models.query.QuerySet):
+    elif (isinstance(src, list) or
+            isinstance(src, models.query.QuerySet) or
+            isinstance(src, set)):
         return [subs(i) for i in src]
 
     elif isinstance(src, dict):
